@@ -1,3 +1,10 @@
+"""
+.. include:: ../README.md
+.. include:: ../TUTORIAL.md
+.. include:: ../CLI.md
+.. include:: ../CONTRIBUTE.md
+"""
+__docformat__ = "google"
 from .collection import Collection, Enum
 from .fields import (StringField, IntegerField, DateField, DateTimeField, BooleanField, FloatField, EmailField,
                      EnumField, ReferenceField, ManyToManyField, SlugField)
